==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Help/About/ts/About_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>About</name>
    <message>
        <source>&amp;About</source>
        <translatorcomment>--google--
&amp;Sobre %1</translatorcomment>
        <translation type="obsolete">&amp;Sobre</translation>
    </message>
    <message>
        <location filename="../About.js" line="+62"/>
        <source>About %1</source>
        <translation>Sobre %1</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Revision:</source>
        <translation>Revisão:</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation>%1 é baseado em QCAD, um software livre (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation>Isto significa que todos &lt;a href=&apos;%1&apos;&gt;podem se envolver&lt;/a&gt;!</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Portions of this software © 2008-2016 The Qt Company Ltd.</source>
        <translation>Partes deste software © 2008-2016 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>Esse programa é distribuído na esperança que seja útil, mas sem nenhuma garantia, nem mesmo a garantia implicada de comercialização ou propriedade para uso particular.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>No information available</source>
        <translation>Não há informações disponíveis</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>Plugin:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <location line="-115"/>
        <location line="+108"/>
        <source>Version:</source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location line="-95"/>
        <location line="+99"/>
        <source>Qt Version:</source>
        <translation>Qt Versão:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>License:</source>
        <translation>Licença:</translation>
    </message>
    <message>
        <location line="-109"/>
        <location line="+118"/>
        <location line="+12"/>
        <source>Internet:</source>
        <translation>Internet:</translation>
    </message>
    <message>
        <location line="-128"/>
        <source>Build Date:</source>
        <translation>Data de constituição:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Architecture:</source>
        <translation>Arquitetura:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Compiler:</source>
        <translation>Compilador:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation>%1 é um pedido de desenho assistido por computador (CAD).</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is free (open source) software.</source>
        <translation>%1 é um software livre (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation>Plugins e script add-ons estão sujeitos às suas respectivas licenças (ver &quot;Plugins&quot; tab).</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation>Todos os nomes de incêndio ou produtos são marcas comerciais ou marcas comerciais registradas de seus respectivos proprietários.</translation>
    </message>
    <message>
        <source>Portions of this software © 2013 Digia Plc.</source>
        <translation type="vanished">Partes deste software © 2013 Digia Plc.</translation>
    </message>
    <message>
        <source>Portions of this software © 2012 Nokia Corporation and/or its subsidiary(-ies).</source>
        <translation type="vanished">Partes deste software © 2012 Nokia Corporation e / ou de sua controlada(s).</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>No plugins found.</source>
        <translation>Nenhum plugin encontrado.</translation>
    </message>
    <message>
        <location line="+93"/>
        <source>Active</source>
        <translation>Ativo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>Inativo (reiniciar)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>Versão de Avaliação:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>Arquivo:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>Erro:</translation>
    </message>
    <message>
        <source>Community Edition</source>
        <translation type="vanished">Community Edition</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Script Add-Ons</source>
        <translation>Scripts de Add-Ons</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation>Nenhum script add-ons encontrados.</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Credits</source>
        <translation>Créditos</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>&amp;Sobre...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation>Programação</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Translations</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Templates</source>
        <translation>Modelos</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation>Icones</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation>Teste, feedback e pequenas correções</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>About QCAD</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Sobre o QCAD</translation>
    </message>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">sobre:em branco</translation>
    </message>
    <message>
        <location line="+134"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Credits</source>
        <translation>Créditos</translation>
    </message>
    <message>
        <source>About Plugins</source>
        <translation type="obsolete">Sobre o plugins</translation>
    </message>
    <message>
        <source>About Script Add-Ons</source>
        <translation type="obsolete">Sobre o Script Add-Ons</translation>
    </message>
</context>
<context>
    <name>AboutInit</name>
    <message>
        <source>&amp;About...</source>
        <translation type="obsolete">&amp;Sobre...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Help/About/ts/About_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>About</name>
    <message>
        <source>&amp;About</source>
        <translatorcomment>--google--
&amp;Sobre %1</translatorcomment>
        <translation type="obsolete">&amp;Sobre</translation>
    </message>
    <message>
        <location filename="../About.js" line="+63"/>
        <source>About %1</source>
        <translation>Sobre %1</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Revision:</source>
        <translation>Revisão:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation>%1 é baseado em QCAD, um software livre (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation>Isto significa que todos &lt;a href=&apos;%1&apos;&gt;podem se envolver&lt;/a&gt;!</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2016 The Qt Company Ltd.</source>
        <translation type="vanished">Partes deste software © 2008-2016 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>Esse programa é distribuído na esperança que seja útil, mas sem nenhuma garantia, nem mesmo a garantia implicada de comercialização ou propriedade para uso particular.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>No information available</source>
        <translation>Não há informações disponíveis</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>Plugin:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <location line="-128"/>
        <location line="+121"/>
        <source>Version:</source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location line="-111"/>
        <location line="+115"/>
        <source>Qt Version:</source>
        <translation>Qt Versão:</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2017 The Qt Company Ltd.</source>
        <translation type="vanished">Partes deste software © 2008-2017 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>License:</source>
        <translation>Licença:</translation>
    </message>
    <message>
        <location line="-125"/>
        <location line="+134"/>
        <location line="+11"/>
        <source>Internet:</source>
        <translation>Internet:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Build Date:</source>
        <translation>Data de constituição:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Architecture:</source>
        <translation>Arquitetura:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Compiler:</source>
        <translation>Compilador:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License Key:</source>
        <translation>Chave de licença:</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation>%1 é um pedido de desenho assistido por computador (CAD).</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is free (open source) software.</source>
        <translation>%1 é um software livre (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation>Plugins e script add-ons estão sujeitos às suas respectivas licenças (ver &quot;Plugins&quot; tab).</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation>Todos os nomes de incêndio ou produtos são marcas comerciais ou marcas comerciais registradas de seus respectivos proprietários.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Portions of this software © %1 The Qt Company Ltd.</source>
        <translation>Partes deste software © %1 The Qt Company Ltd.</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2018 The Qt Company Ltd.</source>
        <translation type="obsolete">Partes deste software © 2008-2017 The Qt Company Ltd. {2008-2018 ?}</translation>
    </message>
    <message>
        <source>Portions of this software © 2013 Digia Plc.</source>
        <translation type="vanished">Partes deste software © 2013 Digia Plc.</translation>
    </message>
    <message>
        <source>Portions of this software © 2012 Nokia Corporation and/or its subsidiary(-ies).</source>
        <translation type="vanished">Partes deste software © 2012 Nokia Corporation e / ou de sua controlada(s).</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>No plugins found.</source>
        <translation>Nenhum plugin encontrado.</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>Active</source>
        <translation>Ativo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>Inativo (reiniciar)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>Versão de Avaliação:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>Arquivo:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>Erro:</translation>
    </message>
    <message>
        <source>Community Edition</source>
        <translation type="vanished">Community Edition</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Script Add-Ons</source>
        <translation>Scripts de Add-Ons</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation>Nenhum script add-ons encontrados.</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Credits</source>
        <translation>Créditos</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>&amp;Sobre...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation>Programação</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Translations</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Templates</source>
        <translation>Modelos</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation>Icones</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation>Teste, feedback e pequenas correções</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>About QCAD</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Sobre o QCAD</translation>
    </message>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">sobre:em branco</translation>
    </message>
    <message>
        <location line="+134"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Credits</source>
        <translation>Créditos</translation>
    </message>
    <message>
        <source>About Plugins</source>
        <translation type="obsolete">Sobre o plugins</translation>
    </message>
    <message>
        <source>About Script Add-Ons</source>
        <translation type="obsolete">Sobre o Script Add-Ons</translation>
    </message>
</context>
<context>
    <name>AboutInit</name>
    <message>
        <source>&amp;About...</source>
        <translation type="obsolete">&amp;Sobre...</translation>
    </message>
</context>
</TS>
